@@ -24,20 +24,16 @@
 
 #include <KPluginFactory>
 
-K_PLUGIN_FACTORY_WITH_JSON(QtFrameBufferPluginFactory, "krfb_framebuffer_qt.json",
-			   registerPlugin<QtFrameBufferPlugin>();)
+K_PLUGIN_CLASS(QtFrameBufferPlugin)
 
 QtFrameBufferPlugin::QtFrameBufferPlugin(QObject *parent, const QVariantList &args)
     : FrameBufferPlugin(parent, args)
 {
 }
 
-QtFrameBufferPlugin::~QtFrameBufferPlugin()
-{
-}
-
-FrameBuffer *QtFrameBufferPlugin::frameBuffer(WId id)
+FrameBuffer *QtFrameBufferPlugin::frameBuffer(WId id, const QVariantMap &args)
 {
+    Q_UNUSED(args);
     return new QtFrameBuffer(id);
 }
 
